import redis from 'redis';

class RedisDB {
  client = null;
  async connect() {
    if(process.env.REDIS_CONNECTION_URL) {
      this.client = redis.createClient({ url: process.env.REDIS_CONNECTION_URL });
    } else {
      this.client = redis.createClient();
    }
    this.client.connect();
  }
  async disconnect() {
    if(this.client) {
      await this.client.disconnect();
    }
  }
  async get(key) {
    return await this.client.get(key);
  }
  async set(key, value, expirationTime = null) {
    const parameters = { NX: false };
    if(expirationTime) {
      parameters.PX = expirationTime;
    }
    return await this.client.set(key, value, parameters);
  }
}
export { RedisDB };
export default new RedisDB();
