import fs from 'node:fs';
import path from 'node:path';

class Image {

  static allImage = {};

  async loadImages() {
    const folderPath = process.env.IMAGES_PATH;
    if(!folderPath) return;
    return new Promise((resolve, reject) => {
      fs.readdir(folderPath, (err, files) => {
        if (err) return reject(err);

        const promises = files.map(file => {
          const filePath = path.join(folderPath, file);
          return new Promise((resolveFile, rejectFile) => {
            fs.readFile(filePath, 'binary', (err, data) => {
              if (err) return rejectFile(err);
              const base64Image = Buffer.from(data, 'binary').toString('base64');
              Image.allImage[file] = `data:image/webp;base64,${base64Image}`;
              resolveFile({ filename: file, content: data });
            });
          });
        });

        Promise.all(promises)
          .then(results => resolve(results))
          .catch(err => reject(err));
      });
    });
  }

  getLogoImage() {
    return Image.allImage['giraffas.webp'] || null;
  }
}

export default new Image();