import express from 'express';
// import LogMiddleware from '../middleware/Log.js';
import AuthMiddleware from '../middleware/Auth.js';
import xml from 'xml-js';
import cors from 'cors';

class App {
  minifyXmlObj(xmlObj) {
    Object.keys(xmlObj).forEach((key) => {
      if(typeof xmlObj[key] === 'object' && !Array.isArray(xmlObj[key])) {
        if(xmlObj[key]._text) {
          xmlObj[key] = xmlObj[key]._text;
        } else {
          this.minifyXmlObj(xmlObj[key]);
        }
      } else if (Array.isArray(xmlObj[key])) {
          xmlObj[key].forEach(subitem => this.minifyXmlObj(subitem));
      }
    });
  }
  register(server) {
    server.use(cors());
    server.use(express.raw({ type: 'application/xml' }));
    server.use((req, res, next) => {
      const originalSend = res.send;
      res.send = function(data) {
        const xmlOptions = { compact: true, spaces: 2 };
        const hasResponseJson = req.query.responseType === 'json'
        const toXml = (data, options) => {
          const xmlContent = xml.js2xml({ root: { data } }, options);
          const xmlHeader = '<?xml version="1.0" encoding="UTF-8"?>\n';
          return xmlHeader.concat(xmlContent);
        }
        const responseData = hasResponseJson ? data : toXml(data, xmlOptions);
        originalSend.call(res, responseData);
      }
      if (['GET', 'OPTIONS'].includes(req.method)) {
        return next();
      }
      let body = req.body.toString();
      body = xml.xml2js(body, { compact: true, ignoreComment: true, ignoreDeclaration: true });
      if(body.root && body.root.data) {
        body = body.root.data;
        this.minifyXmlObj(body);
      }
      req.body = body;
      next();
    });
    // server.use(express.json());
    // LogMiddleware.register(server);
    AuthMiddleware.register(server);
    if (process.env.IMAGES_PATH) {
      server.use('/image', express.static(process.env.IMAGES_PATH));
    }
  }
}

export default new App()
